<?php

namespace Drupal\pwdgen\Form;

/**
 * @file
 * Password Generator Form Settings.
 */

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class Password Generator Form Settings.
 *
 * @package Drupal\pwdgen\Form
 */
class PwdGenFormSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'pwdgen.admin_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pwdgen_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('pwdgen.settings');
    $form['symbols'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Symbol text'),
      '#description' => $this->t('List of symbols to use as replacement of crypted text.'),
      '#default_value' => $config->get('symbols'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Remove spaces.
    $symbol = str_replace(' ', '', $form_state->getValue('symbols'));
    $config = $this->configFactory->getEditable('pwdgen.settings');
    $config->set('symbols', $symbol)
      ->save();
    parent::submitForm($form, $form_state);
  }

}
